@@ -20,7 +20,7 @@
 # 
 #----------------------------------------------------------------------------
 #
-# $Id: Document.pm,v 2.7 2001/03/30 08:09:23 abw Exp $
+# $Id: Document.pm,v 2.14 2001/06/15 14:30:56 abw Exp $
 #
 #============================================================================
 
@@ -33,7 +33,7 @@ use vars qw( $VERSION $ERROR $COMPERR $DEBUG $AUTOLOAD );
 use base qw( Template::Base );
 use Template::Constants;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.7 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.14 $ =~ /(\d+)\.(\d+)/);
 
 
 #========================================================================
@@ -238,7 +238,7 @@ sub write_perl_file {
     $metadata = join('', 
 		       map { 
 			   my $x = $metadata->{ $_ }; 
-			   $x =~ s/['\\]/\\$1/g; 
+			   $x =~ s/(['\\])/\\$1/g; 
 			   "'$_' => '$x',\n";
 		       } keys %$metadata);
 
@@ -440,9 +440,13 @@ Andy Wardley E<lt>abw@kfs.orgE<gt>
 
 L<http://www.andywardley.com/|http://www.andywardley.com/>
 
+
+
+
 =head1 VERSION
 
-Template Toolkit version 2.01, released on 30th March 2001.
+2.13, distributed as part of the
+Template Toolkit version 2.03, released on 15 June 2001.
 
 =head1 COPYRIGHT
 
@@ -455,5 +459,3 @@ modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<Template|Template>, L<Template::Parser|Template::Parser>
-
-
