@@ -19,7 +19,7 @@
 #
 #----------------------------------------------------------------------------
 #
-# $Id: Plugin.pm,v 2.6 2001/03/30 08:09:23 abw Exp $
+# $Id: Plugin.pm,v 2.13 2001/06/15 14:30:56 abw Exp $
 #
 #============================================================================
 
@@ -33,7 +33,7 @@ use Template::Base;
 use vars qw( $VERSION $DEBUG $ERROR $AUTOLOAD );
 use base qw( Template::Base );
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.6 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.13 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0;
 
 
@@ -73,6 +73,12 @@ sub load {
 #------------------------------------------------------------------------
 
 sub new {
+    my $class = shift;
+    bless {
+    }, $class;
+}
+
+sub old_new {
     my ($class, $context, $delclass, @params) = @_;
     my ($delegate, $delmod);
 
@@ -372,9 +378,13 @@ Andy Wardley E<lt>abw@kfs.orgE<gt>
 
 L<http://www.andywardley.com/|http://www.andywardley.com/>
 
+
+
+
 =head1 VERSION
 
-Template Toolkit version 2.01, released on 30th March 2001.
+2.12, distributed as part of the
+Template Toolkit version 2.03, released on 15 June 2001.
 
 =head1 COPYRIGHT
 
@@ -387,5 +397,3 @@ modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<Template|Template>, L<Template::Plugins|Template::Plugins>, L<Template::Context|Template::Context>
-
-
