@@ -65,18 +65,18 @@
 #
 #----------------------------------------------------------------------------
 #
-# $Id: Context.pm 1055 2007-04-27 11:50:40Z abw $
+# $Id: Context.pm,v 1.3 2001/06/15 14:30:56 abw Exp $
 #
 #============================================================================
 
 package Template::Stash::Context;
 
-use strict;
-use warnings;
-use Template::Stash;
+require 5.004;
 
-our $VERSION = 1.63;
-our $DEBUG   = 0 unless defined $DEBUG;
+use strict;
+use vars qw( $VERSION $DEBUG $ROOT_OPS $SCALAR_OPS $HASH_OPS $LIST_OPS );
+
+$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 
 #========================================================================
@@ -84,31 +84,133 @@ our $DEBUG   = 0 unless defined $DEBUG;
 #========================================================================
 
 #------------------------------------------------------------------------
-# copy virtual methods from those in the regular Template::Stash
+# Definitions of various pseudo-methods.  ROOT_OPS are merged into all
+# new Template::Stash objects, and are thus default global functions.
+# SCALAR_OPS are methods that can be called on a scalar, and ditto 
+# respectively for LIST_OPS and HASH_OPS
 #------------------------------------------------------------------------
 
-our $ROOT_OPS = { 
-    %$Template::Stash::ROOT_OPS,
+$ROOT_OPS = {
+    'inc'  => sub { local $^W = 0; my $item = shift; ++$item }, 
+    'dec'  => sub { local $^W = 0; my $item = shift; --$item }, 
     defined $ROOT_OPS ? %$ROOT_OPS : (),
 };
 
-our $SCALAR_OPS = { 
-    %$Template::Stash::SCALAR_OPS,
-    'array' => sub { return [$_[0]] },
+$SCALAR_OPS = {
+    'item'    => sub {   $_[0] },
+    'list'    => sub { [ $_[0] ] },
+    'hash'    => sub { { 0 => $_[0] } },
+    'length'  => sub { length $_[0] },
+    'defined' => sub { return 1 },
+    'array'   => sub { return [$_[0]] },
+    'repeat'  => sub { 
+	my ($str, $count) = @_;
+	$str = '' unless defined $str;  $count ||= 1;
+	return $str x $count;
+    },
+    'search'  => sub { 
+	my ($str, $pattern) = @_;
+	return $str unless defined $str and $pattern;
+	return $str =~ /$pattern/;
+    },
+    'replace'  => sub { 
+	my ($str, $search, $replace) = @_;
+	$replace = '' unless defined $replace;
+	return $str unless defined $str and $search;
+	$str =~ s/$search/$replace/g;
+#	print STDERR "s [ $search ] [ $replace ] g\n";
+#	eval "\$str =~ s$search$replaceg";
+	return $str;
+    },
+    'split'   => sub { 
+	my ($str, $split, @args) = @_;
+	$str = '' unless defined $str;
+	return [ defined $split ? split($split, $str, @args)
+				: split(' ', $str, @args) ];
+    },
     defined $SCALAR_OPS ? %$SCALAR_OPS : (),
 };
 
-our $LIST_OPS = { 
-    %$Template::Stash::LIST_OPS,
-    'array' => sub { return $_[0] },
-    defined $LIST_OPS ? %$LIST_OPS : (),
-};
-		    
-our $HASH_OPS = { 
-    %$Template::Stash::HASH_OPS,
+$HASH_OPS = {
+    'item'   => sub { my ($hash, $item) = @_; 
+		      $item = '' unless defined $item;
+		      $hash->{ $item };
+		  },
+    'hash'   => sub { $_[0] },
+    'keys'   => sub { [ keys   %{ $_[0] } ] },
+    'values' => sub { [ values %{ $_[0] } ] },
+    'each'   => sub { [        %{ $_[0] } ] },
+    'list'   => sub { my ($hash, $what) = @_;  $what ||= '';
+		      return ($what eq 'keys')   ? [   keys %$hash ]
+			   : ($what eq 'values') ? [ values %$hash ]
+			   : ($what eq 'each')   ? [ values %$hash ]
+			   : [ map { { key => $_ , value => $hash->{ $_ } } }
+			       keys %$hash ];
+		},
+    'import' => sub { my ($hash, $imp) = @_;
+		      $imp = {} unless ref $imp eq 'HASH';
+		      @$hash{ keys %$imp } = values %$imp;
+		      return '';
+		  },
+    'sort'    => sub {
+	my ($hash) = @_;
+        [ sort { lc $hash->{$a} cmp lc $hash->{$b} } (keys %$hash) ];
+    },
+    'nsort'    => sub {
+	my ($hash) = @_;
+        [ sort { $hash->{$a} <=> $hash->{$b} } (keys %$hash) ];
+    },
     defined $HASH_OPS ? %$HASH_OPS : (),
 };
- 
+
+$LIST_OPS = {
+    'item'    => sub { $_[0]->[ $_[1] || 0 ] },
+    'list'    => sub { $_[0] },
+    'hash'    => sub { my $list = shift; my $n = 0; 
+		       return { map { ($n++, $_) } @$list }; },
+    'push'    => sub { my $list = shift; push(@$list, shift); return '' },
+    'pop'     => sub { my $list = shift; pop(@$list) },
+    'unshift' => sub { my $list = shift; unshift(@$list, shift); return '' },
+    'shift'   => sub { my $list = shift; shift(@$list) },
+    'max'     => sub { local $^W = 0; my $list = shift; $#$list; },
+    'size'    => sub { local $^W = 0; my $list = shift; $#$list + 1; },
+    'first'   => sub { my $list = shift; $list->[0] },
+    'last'    => sub { my $list = shift; $list->[$#$list] },
+    'reverse' => sub { my $list = shift; [ reverse @$list ] },
+    'array'   => sub { return $_[0] },
+    'join'    => sub { 
+	    my ($list, $joint) = @_; 
+	    join(defined $joint ? $joint : ' ', 
+		 map { defined $_ ? $_ : '' } @$list) 
+    },
+    'sort'    => sub {
+	my ($list, $field) = @_;
+	return $list unless $#$list;	    # no need to sort 1 item lists
+	return $field			    # Schwartzian Transform 
+	    ?  map  { $_->[0] }		    # for case insensitivity
+	       sort { $a->[1] cmp $b->[1] }
+	       map  { [ $_, lc $_->{ $field } ] } 
+	       @$list 
+	    :  map  { $_->[0] }
+	       sort { $a->[1] cmp $b->[1] }
+	       map  { [ $_, lc $_ ] } 
+	       @$list
+   },
+   'nsort'    => sub {
+	my ($list, $field) = @_;
+	return $list unless $#$list;	    # no need to sort 1 item lists
+	return $field			    # Schwartzian Transform 
+	    ?  map  { $_->[0] }		    # for case insensitivity
+	       sort { $a->[1] <=> $b->[1] }
+	       map  { [ $_, lc $_->{ $field } ] } 
+	       @$list 
+	    :  map  { $_->[0] }
+	       sort { $a->[1] <=> $b->[1] }
+	       map  { [ $_, lc $_ ] } 
+	       @$list
+    },
+    defined $LIST_OPS ? %$LIST_OPS : (),
+};
 
 
 #========================================================================
@@ -415,7 +517,7 @@ sub _dotop {
 	unless defined($root) and defined($item) and $item !~ /^[\._]/;
 
     if (ref(\$root) eq "SCALAR" && !$lvalue &&
-            (($value = $LIST_OPS->{ $item }) || $item =~ /^-?\d+$/) ) {
+            (($value = $LIST_OPS->{ $item }) || $item =~ /^\d+$/) ) {
         #
         # Promote scalar to one element list, to be processed below.
         #
@@ -442,10 +544,6 @@ sub _dotop {
 	elsif ($value = $HASH_OPS->{ $item }) {
 	    @result = &$value($root, @$args);		    ## @result
 	}
-	elsif (ref $item eq 'ARRAY') {
-	    # hash slice
-	    return [@$root{@$item}];                       ## RETURN
-	}
 	elsif ($value = $SCALAR_OPS->{ $item }) {
 	    #
 	    # Apply scalar ops to every hash element, in place.
@@ -472,16 +570,12 @@ sub _dotop {
                 $root->[$i] = &$value($root->[$i], @$args); ## @result
             }
 	}
-	elsif ($item =~ /^-?\d+$/) {
+	elsif ($item =~ /^\d+$/) {
 	    $value = $root->[$item];
             ($ret, $retVal, @result) = _dotop_return($value, $args, $returnRef,
                                                      $scalarContext);
             return $retVal if ( $ret );                     ## RETURN
 	}
-        elsif (ref $item eq 'ARRAY' ) {
-            # array slice
-            return [@$root[@$item]];                        ## RETURN
-        }
     }
 
     # NOTE: we do the can-can because UNIVSERAL::isa($something, 'UNIVERSAL')
@@ -617,7 +711,7 @@ sub _assign {
 	return ($root->{ $item } = $value)			## RETURN
 	    unless $default && $root->{ $item };
     }
-    elsif ($rootref eq 'ARRAY' && $item =~ /^-?\d+$/) {
+    elsif ($rootref eq 'ARRAY' && $item =~ /^\d+$/) {
 	# or set a list item by index number
 	return ($root->[$item] = $value)			## RETURN
 	    unless $default && $root->{ $item };
@@ -755,22 +849,22 @@ new features very much.  One nagging implementation problem is that the
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
+Andy Wardley E<lt>abw@kfs.orgE<gt>
 
-L<http://wardley.org/|http://wardley.org/>
+L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 
 
 
 =head1 VERSION
 
-1.63, distributed as part of the
-Template Toolkit version 2.19, released on 27 April 2007.
+1.02, distributed as part of the
+Template Toolkit version 2.03, released on 15 June 2001.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
-
+  Copyright (C) 1996-2001 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1998-2001 Canon Research Centre Europe Ltd.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -778,13 +872,3 @@ modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<Template::Stash|Template::Stash>
-
-=cut
-
-# Local Variables:
-# mode: perl
-# perl-indent-level: 4
-# indent-tabs-mode: nil
-# End:
-#
-# vim: expandtab shiftwidth=4:
